==> riedev_graph-0.1.0.tar.gz: test/depthSearch_test.dart <==
import 'package:riedev_graph/graph.dart';
import "package:riedev_graph/traversal/depthSearch.dart";
import "package:test/test.dart";

void main() {
  /*
        1
      /   \ 
     2     3  10
    / \   / \ /
   4    5    6
   |    |    |
   11   7    |
   |    |    |
   |    8    |
   |    \   /
   |      9
   12    | \
    \    | 14
     \  /
      13 
*/
  group('DepthSearch', () {
    Edge<int> e1;
    Edge<int> e2;
    Edge<int> e3;
    Edge<int> e4;
    Edge<int> e5;
    Edge<int> e6;
    Edge<int> e7;
    Edge<int> e8;
    Edge<int> e9;
    Edge<int> e10;
    Edge<int> e11;
    Edge<int> e12;
    Edge<int> e13;
    Edge<int> e14;
    Edge<int> e15;
    Edge<int> e16;

    List<Edge<int>> edges;

    Graph<int, Edge<int>> g;

    setUp(() {
      g = Graph<int, Edge<int>>(false);

      e1 = const Edge(1, 2);
      e2 = const Edge(1, 3);
      e3 = const Edge(2, 4);
      e4 = const Edge(2, 5);
      e5 = const Edge(3, 5);
      e6 = const Edge(3, 6);
      e7 = const Edge(10, 6);
      e8 = const Edge(4, 11);
      e9 = const Edge(5, 7);
      e10 = const Edge(6, 9);
      e11 = const Edge(11, 12);
      e12 = const Edge(7, 8);
      e13 = const Edge(8, 9);
      e14 = const Edge(9, 14);
      e15 = const Edge(12, 13);
      e16 = const Edge(9, 13);

      edges = [
        e1,
        e2,
        e3,
        e4,
        e5,
        e6,
        e7,
        e8,
        e9,
        e10,
        e11,
        e12,
        e13,
        e14,
        e15,
        e16
      ];
      g.addEdges(edges);
    });

    test('pre depth search test', () {
      var result = preDepthSearch(1, (n) => g.subsequentNodes(n));

      assert(result.length == 13);

      assert(result[0] == 1);
      assert(result[1] == 2);
      assert(result[2] == 4);
      assert(result[3] == 11);
      assert(result[4] == 12);
      assert(result[5] == 13);
      assert(result[6] == 5);
      assert(result[7] == 7);
      assert(result[8] == 8);
      assert(result[9] == 9);
      assert(result[10] == 14);
      assert(result[11] == 3);
      assert(result[12] == 6);
    });

    test('post depth search test', () {
      var result = postDepthSearch2(1, (n) => g.subsequentNodes(n));

      assert(result.length == 13);

      assert(result[0] == 13);
      assert(result[1] == 12);
      assert(result[2] == 11);
      assert(result[3] == 4);
      assert(result[4] == 14);
      assert(result[5] == 9);
      assert(result[6] == 8);
      assert(result[7] == 7);
      assert(result[8] == 5);
      assert(result[9] == 2);
      assert(result[10] == 6);
      assert(result[11] == 3);
      assert(result[12] == 1);
    });
  });
}

==> riedev_graph-0.1.1.tar.gz: test/depthSearch_test.dart <==
import 'package:riedev_graph/graph.dart';
import "package:riedev_graph/traversal/depthSearch.dart";
import "package:test/test.dart";

void main() {
  /*
        1
      /   \ 
     2     3  10
    / \   / \ /
   4    5    6
   |    |    |
   11   7    |
   |    |    |
   |    8    |
   |    \   /
   |      9
   12    | \
    \    | 14
     \  /
      13 
*/
  group('DepthSearch', () {
    Edge<int> e1;
    Edge<int> e2;
    Edge<int> e3;
    Edge<int> e4;
    Edge<int> e5;
    Edge<int> e6;
    Edge<int> e7;
    Edge<int> e8;
    Edge<int> e9;
    Edge<int> e10;
    Edge<int> e11;
    Edge<int> e12;
    Edge<int> e13;
    Edge<int> e14;
    Edge<int> e15;
    Edge<int> e16;

    List<Edge<int>> edges;

    Graph<int, Edge<int>> g;

    setUp(() {
      g = Graph<int, Edge<int>>(false);

      e1 = const Edge(1, 2);
      e2 = const Edge(1, 3);
      e3 = const Edge(2, 4);
      e4 = const Edge(2, 5);
      e5 = const Edge(3, 5);
      e6 = const Edge(3, 6);
      e7 = const Edge(10, 6);
      e8 = const Edge(4, 11);
      e9 = const Edge(5, 7);
      e10 = const Edge(6, 9);
      e11 = const Edge(11, 12);
      e12 = const Edge(7, 8);
      e13 = const Edge(8, 9);
      e14 = const Edge(9, 14);
      e15 = const Edge(12, 13);
      e16 = const Edge(9, 13);

      edges = [
        e1,
        e2,
        e3,
        e4,
        e5,
        e6,
        e7,
        e8,
        e9,
        e10,
        e11,
        e12,
        e13,
        e14,
        e15,
        e16
      ];
      g.addEdges(edges);
    });

    test('pre depth search test', () {
      var result = preDepthSearch(1, (int n) => g.subsequentNodes(n));

      assert(result.length == 13);

      assert(result[0] == 1);
      assert(result[1] == 2);
      assert(result[2] == 4);
      assert(result[3] == 11);
      assert(result[4] == 12);
      assert(result[5] == 13);
      assert(result[6] == 5);
      assert(result[7] == 7);
      assert(result[8] == 8);
      assert(result[9] == 9);
      assert(result[10] == 14);
      assert(result[11] == 3);
      assert(result[12] == 6);
    });

    test('post depth search test', () {
      var result = postDepthSearch2(1, (int n) => g.subsequentNodes(n));

      assert(result.length == 13);

      assert(result[0] == 13);
      assert(result[1] == 12);
      assert(result[2] == 11);
      assert(result[3] == 4);
      assert(result[4] == 14);
      assert(result[5] == 9);
      assert(result[6] == 8);
      assert(result[7] == 7);
      assert(result[8] == 5);
      assert(result[9] == 2);
      assert(result[10] == 6);
      assert(result[11] == 3);
      assert(result[12] == 1);
    });
  });
}
